==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/rendering/XGraphicDevice.hpp <==
#ifndef _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_
#define _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HDL_
#include "com/sun/star/rendering/XGraphicDevice.hdl"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_REALPOINT2D_HPP_
#include "com/sun/star/geometry/RealPoint2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XPARAMETRICPOLYPOLYGON2DFACTORY_HPP_
#include "com/sun/star/rendering/XParametricPolyPolygon2DFactory.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XVOLATILEBITMAP_HPP_
#include "com/sun/star/rendering/XVolatileBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALBEZIERSEGMENT2D_HPP_
#include "com/sun/star/geometry/RealBezierSegment2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBUFFERCONTROLLER_HPP_
#include "com/sun/star/rendering/XBufferController.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XCOLORSPACE_HPP_
#include "com/sun/star/rendering/XColorSpace.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBEZIERPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XBezierPolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XLINEPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XLinePolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_INTEGERSIZE2D_HPP_
#include "com/sun/star/geometry/IntegerSize2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBITMAP_HPP_
#include "com/sun/star/rendering/XBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALSIZE2D_HPP_
#include "com/sun/star/geometry/RealSize2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XGraphicDevice >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.rendering.XGraphicDevice" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::rendering::XGraphicDevice::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XGraphicDevice > * >(0));
}

#endif // _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/rendering/XGraphicDevice.hpp <==
#ifndef _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_
#define _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HDL_
#include "com/sun/star/rendering/XGraphicDevice.hdl"
#endif

#ifndef _COM_SUN_STAR_GEOMETRY_REALPOINT2D_HPP_
#include "com/sun/star/geometry/RealPoint2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XPARAMETRICPOLYPOLYGON2DFACTORY_HPP_
#include "com/sun/star/rendering/XParametricPolyPolygon2DFactory.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XVOLATILEBITMAP_HPP_
#include "com/sun/star/rendering/XVolatileBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_ILLEGALARGUMENTEXCEPTION_HPP_
#include "com/sun/star/lang/IllegalArgumentException.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALBEZIERSEGMENT2D_HPP_
#include "com/sun/star/geometry/RealBezierSegment2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBUFFERCONTROLLER_HPP_
#include "com/sun/star/rendering/XBufferController.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XCOLORSPACE_HPP_
#include "com/sun/star/rendering/XColorSpace.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBEZIERPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XBezierPolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XLINEPOLYPOLYGON2D_HPP_
#include "com/sun/star/rendering/XLinePolyPolygon2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_INTEGERSIZE2D_HPP_
#include "com/sun/star/geometry/IntegerSize2D.hpp"
#endif
#ifndef _COM_SUN_STAR_RENDERING_XBITMAP_HPP_
#include "com/sun/star/rendering/XBitmap.hpp"
#endif
#ifndef _COM_SUN_STAR_GEOMETRY_REALSIZE2D_HPP_
#include "com/sun/star/geometry/RealSize2D.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_SEQUENCE_HXX_
#include "com/sun/star/uno/Sequence.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace rendering {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::rendering::XGraphicDevice const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.rendering.XGraphicDevice" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::rendering::XGraphicDevice > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XGraphicDevice > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::rendering::XGraphicDevice::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::rendering::XGraphicDevice > * >(0));
}

#endif // _COM_SUN_STAR_RENDERING_XGRAPHICDEVICE_HPP_
